## See https://packaging.python.org/guides/single-sourcing-package-version/
## ----- Time-stamp: <2020-07-21 17:51:23 hedfp> ------

__version__ = "0.0b2.dev2", # X.YaN.devM format for now

import astropy
import func_timeout
